import dayjs from "dayjs";
import editForm from "../form.vue";
import { handleTree } from "@/utils/tree";
import { message } from "@/utils/message";
import { ElMessageBox } from "element-plus";
import { usePublicHooks } from "@/hooks/hooks";
import { addDialog } from "@/components/ReDialog";
import { addDrawer } from "@/components/ReDrawer";
import type { FormItemProps } from "./types";
import type { FormItemProps as ApplicationFormItemProps } from "../../utils/types";
import messageTemplate from "../../messageTemplate/index.vue";
import type { PaginationProps } from "@pureadmin/table";
import { getKeyList, deviceDetection } from "@pureadmin/utils";
import messageSceneApi from "@/api/messagePlatform/messageScene";
import applicationApi from "@/api/messagePlatform/application";
import messageGatewayApi from "@/api/messagePlatform/messageGateway";
import messageSceneTemplateApi from "@/api/messagePlatform/messageSceneTemplate";
import { useRouter } from "vue-router";
import {
  menuSendMessageTypeOptions
} from "./enums";
import {
  menuGateWayTypeOptions
} from "@/utils/enums/gatewayType";

import { type Ref, reactive, ref, onMounted, h, toRaw, watch } from "vue";

export function useRole(newFormInline: any) {
  const router = useRouter();
  const form = reactive({
    sceneName: "",
    status: "",
    applicationId: undefined
  });
  const curRow = ref();
  const formRef = ref();
  const dataList = ref([]);
  const pageData = ref<ApplicationFormItemProps>({
    id: 0,
    applicationName: "",
    applicationDescribe: 0,
    systemName: "",
    createBy: "",
    appId: "",
    status: true
  });
  const isShow = ref(false);
  const loading = ref(true);
  const switchLoadMap = ref({});
  const appId = ref(null);
  const { switchStyle } = usePublicHooks();
  const treeProps = {
    value: "id",
    label: "title",
    children: "children"
  };
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    pageNum: 1,
    background: true,
    currentPage: 0
  });
  const columns: TableColumnList = [
    {
      label: "类型编号",
      prop: "sceneCode"
    },
    {
      label: "场景名称",
      prop: "sceneName"
    },
    {
      label: "消息类别",
      cellRenderer: scope => {
        const { sceneMessageType } = scope.row;
        return menuSendMessageTypeOptions.find(
          item => item.value == sceneMessageType
        )?.label;
      }
    },
    {
      label: "发送方式",
      prop: "sendTypeDescribe",
      cellRenderer: scope => {
        const { sendTypeDescribe } = scope.row;
        let array = sendTypeDescribe ? sendTypeDescribe.split(";") : []
        array = array.map(item => {
          let itemValue = item.split(",")
          let res = menuGateWayTypeOptions.find(
            item => item.value == itemValue[0]
          );
          return res ? res.label : ""
        }
        )
        return array.join(",")
      }
    },
    {
      label: "更新时间",
      prop: "updateTime"
    },
    {
      label: "模板配置",
      cellRenderer: scope => {
        const { template } = scope.row;
        return template == '1' ? '已配置' : '未配置'
      }
    },
    {
      label: "状态",
      cellRenderer: scope => (
        <el-switch
          size={scope.props.size === "small" ? "small" : "default"}
          loading={switchLoadMap.value[scope.index]?.loading}
          v-model={scope.row.status}
          active-value={true}
          inactive-value={false}
          active-text="已启用"
          inactive-text="已停用"
          inline-prompt
          style={switchStyle.value}
          onClick={() => onChange(scope as any)}
        />
      ),
      minWidth: 90
    },
    {
      label: "操作",
      fixed: "right",
      width: 210,
      slot: "operation"
    }
  ];
  // const buttonClass = computed(() => {
  //   return [
  //     "!h-[20px]",
  //     "reset-margin",
  //     "!text-gray-500",
  //     "dark:!text-white",
  //     "dark:hover:!text-primary"
  //   ];
  // });

  function onChange({ row, index }) {
    ElMessageBox.confirm(
      `确认要<strong>${row.status === 0 ? "停用" : "启用"
      }</strong><strong style='color:var(--el-color-primary)'>${row.sceneName
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    )
      .then(async () => {
        await messageSceneApi.update(row);
        message(
          `已${row.status === 0 ? "停用" : "启用"}${row.sceneName}`,
          {
            type: "success"
          }
        );
        onSearch();
      })
      .catch(() => {
        !row.status ? (row.status = true) : (row.status = false);
      });
  }

  function handleSizeChange(val: number) {
    console.log(`${val} items per page`);
  }

  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
  }

  function handleSelectionChange(val) {
    console.log("handleSelectionChange", val);
  }
  const handleUpdate = (row?: FormItemProps) => {
    return messageSceneApi.update(row);
  };



  const handleAdd = (row?: FormItemProps) => {
    row.applicationId = pageData.value.id;
    // console.log("11111111111111", row, pageData.value);
    // return;
    return messageSceneApi.add(row);
  };

  async function handleDelete(row?: FormItemProps) {
    ElMessageBox.confirm(
      `确认要<strong>删除消息类型名称为</strong><strong style='color:var(--el-color-primary)'>${row.sceneName
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    ).then(async () => {
      await messageSceneApi.remove(row.id);
      message(`您删除了消息类型名称为${row.sceneName}的这条数据`, {
        type: "success"
      });
      onSearch();
    });
  }

  async function onSearch() {
    loading.value = true;
    console.log("222", newFormInline);

    const { data } = await applicationApi.fetchByAppId(newFormInline.value.appId);

    pageData.value = data;
    form.applicationId = pageData.value.id;
    setTimeout(() => {
      loading.value = false;
    }, 500);
    onSearchList();
  }
  async function onSearchList() {
    const { data } = await messageSceneApi.fetch(toRaw(form));
    dataList.value = data.records;
  }

  const resetForm = formEl => {
    if (!formEl) return;
    formEl.resetFields();

    onSearch();
  };
  /** 跳转消息类型管理 */
  function handleNavigation(row?: FormItemProps) {
    router.push("/messagePlatform/applicationMange/messageTemplate");
  }

  const handleBack = () => {
    router.back();
  };

  const renderSendTypeList = (value?) => {
    let array = value ? value.split(";") : []
    array = array.map(item => {
      let itemValue = item.split(",")
      return { type: itemValue[0], gateway: itemValue[1] }
    }
    )
    return menuGateWayTypeOptions.map((item, index) => {
      if (array.find(item1 => item1.type == item.value)) {
        let item1 = array.find(item1 => item1.type == item.value)
        return { type: true, gateway: Number(item1.gateway), gatewayList: [], label: item.label, value: item.value }
      }
      return { type: "", gateway: "", gatewayList: [], label: item.label, value: item.value }
    })

  }

  function openDialog(title = "新增", row?: FormItemProps) {
    addDialog({
      title: `${title}消息类型`,
      top: "10vh",
      props: {
        formInline: {
          id: row?.id ?? "",
          sceneCode: row?.sceneCode ?? "",
          sceneMessageType: row?.sceneMessageType ?? "",
          sendTypeDescribe: row?.sendTypeDescribe ?? "",
          applicationId: row?.applicationId ?? "",
          status: row?.status ?? "",
          remark: row?.remark ?? "",
          sceneName: row?.sceneName ?? "",
          sendTypeList: renderSendTypeList(row?.sendTypeDescribe)
        }
      },
      width: "50%",
      draggable: true,
      fullscreen: deviceDetection(),
      fullscreenIcon: true,
      closeOnClickModal: false,
      contentRenderer: () => h(editForm, { ref: formRef, formInline: null }),
      beforeSure: (done, { options }) => {
        const FormRef = formRef.value.getRef();
        const curData = options.props.formInline as FormItemProps;
        function chores() {
          message(`您${title}了网关名称为${curData.sceneName}的这条数据`, {
            type: "success"
          });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        FormRef.validate(async valid => {
          if (valid) {
            console.log("curData", curData);
            curData.sendTypeList = curData.sendTypeList.reduce((pre, cur) => {
              console.log(cur, pre);
              if (cur.type && cur.gateway) {
                pre.push(`${cur.value},${cur.gateway}`)
              }
              return pre
            }, [])
            curData.sendTypeDescribe = curData.sendTypeList.join(";")
            // 表单规则校验通过
            if (title === "新增") {
              // 实际开发先调用新增接口，再进行下面操作
              await handleAdd(curData);
              chores();
            } else {
              await handleUpdate(curData);
              chores();
            }
          }
        });
      }
    });
  }

  function openDrawer(row) {
    addDrawer({
      title: "消息类型管理",
      size: "90%",
      direction: "ltr",
      props: {
        formInline: {
          id: 0,
          sendTypeDescribe: row?.sendTypeDescribe ?? "",
          sceneName: row?.sceneName ?? "",
          sceneId: row?.id ?? 0,
          applicationId: row?.applicationId ?? 0,
          gatewayType: "",
          templateContent: "",
          autoParameterDefine: row.autoParameterDefine ?? "",
          status: "",
        }
      },
      contentRenderer: () => h(messageTemplate),
      hideFooter: true,
      beforeSure: async (done, { options }) => {
        const curData = options.props.formInline as FormItemProps;
        function chores() {
          // message(`您${title}了网关名称为${curData.sceneName}的这条数据`, {
          //   type: "success"
          // });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        if (curData.id) {
          // 实际开发先调用新增接口，再进行下面操作
          await handleTemplateUpdate(curData);
          chores();
        } else {
          await handleTemplateAdd(curData);

          chores();
        }
        onSearch()

      }
    })
  }

  const handleTemplateAdd = (row) => {
    messageSceneTemplateApi.add(row)
  }
  const handleTemplateUpdate = (row) => {
    messageSceneTemplateApi.update(row)
  }


  /** 高亮当前权限选中行 */
  function rowStyle({ row: { id } }) {
    return {
      cursor: "pointer",
      background: id === curRow.value?.id ? "var(--el-fill-color-light)" : ""
    };
  }


  onMounted(async () => {
    const { appId: id } = router.currentRoute.value.query;
    appId.value = id ?? "";
    onSearch();
  });


  return {
    form,
    isShow,
    curRow,
    loading,
    columns,
    rowStyle,
    dataList,
    pagination,
    onSearch,
    resetForm,
    openDialog,
    handleDelete,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    handleNavigation,
    pageData,
    handleBack,
    openDrawer
  };
}
