import dayjs from "dayjs";
import editForm from "../form.vue";
import { message } from "@/utils/message";
import { ElMessageBox } from "element-plus";
import { usePublicHooks } from "@/hooks/hooks";
import { addDialog } from "@/components/ReDialog";
import { addDrawer } from "@/components/ReDrawer";
import type { FormItemProps } from "./types";
import type { PaginationProps } from "@pureadmin/table";
import messageGatewayApi from "@/api/messagePlatform/messageGateway";
import dynamicParameterApi from "@/api/messagePlatform/dynamicParameter";
import { menuGateWayTypeOptions } from "@/utils/enums/gatewayType";
import { useMessagePlatformHook } from "@/store/modules/messagePlatform";
import { type Ref, reactive, ref, onMounted, h, toRaw, watch } from "vue";
export function useMessageGateway() {
  const form = reactive({
    gatewayName: "",
    gatewayType: "",
    status: "",
    pageNum: 1,
    pageSize: 10
  });
  const curRow = ref();
  const formRef = ref();
  const dataList = ref([]);
  const typeList = ref([]);
  const treeData = ref([]);
  const isShow = ref(false);
  const loading = ref(true);
  const isLinkage = ref(false);
  const treeSearchValue = ref();
  const switchLoadMap = ref({});
  const isExpandAll = ref(false);
  const isSelectAll = ref(false);
  const deleteDialogVisible = ref(false);
  const { switchStyle } = usePublicHooks();
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true,
    pageNum: 0
  });
  const columns: TableColumnList = [
    {
      label: "网关名称",
      prop: "gatewayName"
    },
    {
      label: "网关类型",
      cellRenderer: scope => {
        const { gatewayType } = scope.row;
        const res = menuGateWayTypeOptions.find(
          item => item.value == gatewayType
        );
        return res ? res.label : "";
      }
    },

    {
      label: "动态属性类名",
      cellRenderer: scope => {
        const { parameterDefineId } = scope.row;
        const res = typeList.value.find(item => item.id == parameterDefineId);
        return res ? res.name : "";
      }
    },
    {
      label: "创建人",
      prop: "createBy"
    },
    {
      label: "状态",
      cellRenderer: scope => (
        <el-switch
          size={scope.props.size === "small" ? "small" : "default"}
          loading={switchLoadMap.value[scope.index]?.loading}
          v-model={scope.row.status}
          active-value={true}
          inactive-value={false}
          active-text="已启用"
          inactive-text="已停用"
          inline-prompt
          style={switchStyle.value}
          onClick={() => onChange(scope as any)}
        />
      ),
      minWidth: 90
    },
    {
      label: "创建时间",
      prop: "createTime",
      minWidth: 160,
      formatter: ({ createTime }) =>
        dayjs(createTime).format("YYYY-MM-DD HH:mm:ss")
    },
    {
      label: "操作",
      fixed: "right",
      width: 210,
      slot: "operation"
    }
  ];
  // const buttonClass = computed(() => {
  //   return [
  //     "!h-[20px]",
  //     "reset-margin",
  //     "!text-gray-500",
  //     "dark:!text-white",
  //     "dark:hover:!text-primary"
  //   ];
  // });
  const onSearchTypeList = async () => {
    typeList.value = dataList.value =
      useMessagePlatformHook().$state.dynamicParameterList;
  };

  function onChange({ row, index }) {
    ElMessageBox.confirm(
      `确认要<strong>${row.status === 0 ? "停用" : "启用"
      }</strong><strong style='color:var(--el-color-primary)'>${row.gatewayName
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    )
      .then(async () => {
        await messageGatewayApi.update(row);
        message(`已${row.status === 0 ? "停用" : "启用"}${row.gatewayName}`, {
          type: "success"
        });
        onSearch();
      })
      .catch(() => {
        !row.status ? (row.status = true) : (row.status = false);
      })
  }

  function handleSizeChange(val: number) {
    console.log(`${val} items per page`);
  }

  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
  }

  function handleSelectionChange(val) {
    console.log("handleSelectionChange", val);
  }

  async function onSearch() {
    loading.value = true;
    const { data } = await messageGatewayApi.fetch(toRaw(form));
    dataList.value = data.records;
    pagination.total = data.total;
    pagination.pageSize = data.pageSize;
    pagination.currentPage = data.pageNum;

    setTimeout(() => {
      loading.value = false;
    }, 500);
  }

  const handleUpdate = (row?: FormItemProps) => {
    return messageGatewayApi.update(row);
  };

  const handleAdd = (row?: FormItemProps) => {
    return messageGatewayApi.add(row);
  };

  async function handleDelete(row?: FormItemProps) {
    ElMessageBox.confirm(
      `确认要<strong>删除网关名称为</strong><strong style='color:var(--el-color-primary)'>${row.gatewayName
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    ).then(async () => {
      await messageGatewayApi.remove(row.id);
      message(`您删除了动态属性名称为${row.gatewayName}的这条数据`, {
        type: "success"
      });
      onSearch();
    })
  }

  const resetForm = formEl => {
    console.log("表单ref", formEl);
    if (!formEl) return;
    formEl.resetFields();
    onSearch();
  };

  function openDialog(title = "新增", row?: FormItemProps) {
    addDrawer({
      title: `${title}网关`,
      direction: "ltr",
      props: {
        formInline: {
          id: row?.id ?? "",
          /** 网关名称 */
          gatewayName: row?.gatewayName ?? "",
          /** 网关类型 */
          gatewayType: row?.gatewayType ? Number(row.gatewayType) : null,
          /** 网关消息参数定义id */
          parameterDefineId: row?.parameterDefineId ?? "",
          /** 网关消息参数 */
          parameter: row?.parameter ? JSON.parse(row.parameter) : "",
          /** 状态 */
          status: row?.status ?? true,
          /** 是否默认 */
          default: row?.default ?? true,
          /** 备注 */
          remark: row?.remark ?? ""
        }
      },
      size: "40%",
      contentRenderer: () => h(editForm, { ref: formRef, formInline: null }),
      beforeSure: (done, { options }) => {
        const FormRef = formRef.value.getRef();
        const curData = options.props.formInline as FormItemProps;
        function chores() {
          message(`您${title}了网关名称为${curData.gatewayName}的这条数据`, {
            type: "success"
          });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        FormRef.validate(async valid => {
          if (valid) {
            console.log("curData", curData);
            curData.parameter = JSON.stringify(curData.parameter);
            // curData.parameter =
            // 表单规则校验通过
            if (title === "新增") {
              // 实际开发先调用新增接口，再进行下面操作
              await handleAdd(curData);
              chores();
            } else {
              await handleUpdate(curData);
              chores();
            }
          }
        });
      }
    });
  }

  /** 高亮当前权限选中行 */
  function rowStyle({ row: { id } }) {
    return {
      cursor: "pointer",
      background: id === curRow.value?.id ? "var(--el-fill-color-light)" : ""
    };
  }


  onMounted(async () => {
    useMessagePlatformHook()
      .saveDynamicParameterList()
      .then(() => {
        onSearchTypeList();
        onSearch();
      });
  });

  return {
    form,
    isShow,
    curRow,
    loading,
    columns,
    rowStyle,
    dataList,
    treeData,
    isLinkage,
    pagination,
    isExpandAll,
    isSelectAll,
    treeSearchValue,
    // buttonClass,
    onSearch,
    resetForm,
    openDialog,
    handleDelete,
    // handleDatabase,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    deleteDialogVisible
  };
}
